@@ -2,16 +2,12 @@ import os
 
 from mainsequence.client import Constant as _C
 
-from .data_interface import DateInfo, MockDataInterface, MSInterface
+from .data_interface import DateInfo,  MSInterface
 
 
-def _make_backend():
-    backend = os.getenv("MSI_DATA_BACKEND", "mainsequence").lower()
-    return MSInterface() if backend == "mainsequence" else MockDataInterface()
-
 
 # export a single, uniform instance
-data_interface = _make_backend()
+data_interface = MSInterface() 
 
 
 constants_to_create = dict(
