@@ -1,3 +1,3 @@
 from .base_instrument import InstrumentModel as Instrument
-from .bond import FixedRateBond, FloatingRateBond
+from .bond import FixedRateBond, FloatingRateBond,ZeroCouponBond
 from .position import Position, PositionLine
