@@ -120,12 +120,16 @@ class DataAccessMixin:
         return repr
 
     def get_last_observation(self, asset_list: Optional[list[ms_client.AssetMixin]]=None):
-        update_statistics = self.get_update_statistics()
-        if asset_list is not None:
-            update_statistics = update_statistics.update_assets(asset_list=asset_list)
-        update_range_map = update_statistics.get_update_range_map_great_or_equal()
-        last_observation = self.get_ranged_data_per_asset(update_range_map)
-        return last_observation
+        # update_statistics = self.get_update_statistics()
+        # if asset_list is not None:
+        #     update_statistics = update_statistics.update_assets(asset_list=asset_list)
+        # update_range_map = update_statistics.get_update_range_map_great_or_equal()
+        # last_observation = self.get_ranged_data_per_asset(update_range_map)
+        # return last_observation
+        return self.local_persist_manager.get_last_observation(
+            asset_list=asset_list,
+        )
+
 
     def get_pickle_path_from_time_serie(self) -> str:
         path = build_operations.get_pickle_path(
@@ -540,6 +544,7 @@ class DataNode(DataAccessMixin, ABC):
     """
 
     OFFSET_START = datetime.datetime(2018, 1, 1, tzinfo=pytz.utc)
+    OPEN_TO_PUBLIC=False # flag for enterprise data providers that want to open their data nmodes
     _ARGS_IGNORE_IN_STORAGE_HASH = []
 
     # --- Dunder & Serialization Methods ---
@@ -909,6 +914,7 @@ class DataNode(DataAccessMixin, ABC):
             time_serie_source_code=time_serie_source_code,
             data_source=self.data_source,
             build_configuration_json_schema=self.build_configuration_json_schema,
+            open_to_public=self.OPEN_TO_PUBLIC
         )
 
     def set_relation_tree(self):
@@ -983,7 +989,7 @@ class DataNode(DataAccessMixin, ABC):
 
     def run(
         self,
-        debug_mode: bool,
+        debug_mode: bool=True,
         *,
         update_tree: bool = True,
         force_update: bool = False,
